@@ -21,21 +21,29 @@
 #ifndef vte_iso2022_h_included
 #define vte_iso2022_h_included
 
-#ident "$Id"
+#ident "$Id: iso2022.h,v 1.11 2003/04/14 19:41:12 nalin Exp $"
 
 #include <glib.h>
 #include <glib-object.h>
-#include "table.h"
+#include "matcher.h"
 
 G_BEGIN_DECLS
 
 struct _vte_iso2022 *_vte_iso2022_new(void);
 struct _vte_iso2022 *_vte_iso2022_copy(struct _vte_iso2022 *original);
 void _vte_iso2022_free(struct _vte_iso2022 *p);
+gunichar _vte_iso2022_substitute_single(gunichar mapname, gunichar c);
 gssize _vte_iso2022_substitute(struct _vte_iso2022 *state,
 			       gunichar *instring, gssize length,
 			       gunichar *outstring,
-			       struct _vte_table *specials);
+			       struct _vte_matcher *specials);
+
+#define VTE_ISO2022_ENCODED_WIDTH_BIT_OFFSET	28
+#define VTE_ISO2022_ENCODED_WIDTH_MASK		(3 << VTE_ISO2022_ENCODED_WIDTH_BIT_OFFSET)
+#define VTE_ISO2022_HAS_ENCODED_WIDTH(__c)	(((__c) & VTE_ISO2022_ENCODED_WIDTH_MASK) != 0)
+gssize _vte_iso2022_get_encoded_width(gunichar c);
+gboolean _vte_iso2022_is_ambiguous(gunichar c);
+gssize _vte_iso2022_unichar_width(gunichar c);
 
 G_END_DECLS
 
